using namespace System.Management.Automation
using namespace System.Management.Automation.Language

Register-ArgumentCompleter -Native -CommandName 'imdl' -ScriptBlock {
    param($wordToComplete, $commandAst, $cursorPosition)

    $commandElements = $commandAst.CommandElements
    $command = @(
        'imdl'
        for ($i = 1; $i -lt $commandElements.Count; $i++) {
            $element = $commandElements[$i]
            if ($element -isnot [StringConstantExpressionAst] -or
                $element.StringConstantType -ne [StringConstantType]::BareWord -or
                $element.Value.StartsWith('-')) {
                break
        }
        $element.Value
    }) -join ';'

    $completions = @(switch ($command) {
        'imdl' {
            [CompletionResult]::new('-c', 'c', [CompletionResultType]::ParameterName, 'Print colorful output according to `WHEN`. When `auto`, the default, colored output is only enabled if imdl detects that it is connected to a terminal, the `NO_COLOR` environment variable is not set, and the `TERM` environment variable is not set to `dumb`.')
            [CompletionResult]::new('--color', 'color', [CompletionResultType]::ParameterName, 'Print colorful output according to `WHEN`. When `auto`, the default, colored output is only enabled if imdl detects that it is connected to a terminal, the `NO_COLOR` environment variable is not set, and the `TERM` environment variable is not set to `dumb`.')
            [CompletionResult]::new('-u', 'u', [CompletionResultType]::ParameterName, 'Enable unstable features. To avoid premature stabilization and excessive version churn, unstable features are unavailable unless this flag is set. Unstable features are not bound by semantic versioning stability guarantees, and may be changed or removed at any time.')
            [CompletionResult]::new('--unstable', 'unstable', [CompletionResultType]::ParameterName, 'Enable unstable features. To avoid premature stabilization and excessive version churn, unstable features are unavailable unless this flag is set. Unstable features are not bound by semantic versioning stability guarantees, and may be changed or removed at any time.')
            [CompletionResult]::new('-t', 't', [CompletionResultType]::ParameterName, 'Disable automatic terminal detection and behave as if both standard output and standard error are connected to a terminal.')
            [CompletionResult]::new('--terminal', 'terminal', [CompletionResultType]::ParameterName, 'Disable automatic terminal detection and behave as if both standard output and standard error are connected to a terminal.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('torrent', 'torrent', [CompletionResultType]::ParameterValue, 'Subcommands related to the BitTorrent protocol.')
            [CompletionResult]::new('completions', 'completions', [CompletionResultType]::ParameterValue, 'Print shell completion scripts to standard output.')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Prints this message or the help of the given subcommand(s)')
            break
        }
        'imdl;torrent' {
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a .torrent file.')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Generate a magnet link from a .torrent file.')
            [CompletionResult]::new('piece-length', 'piece-length', [CompletionResultType]::ParameterValue, 'Display information about automatic piece length selection.')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Display information about a .torrent file.')
            [CompletionResult]::new('stats', 'stats', [CompletionResultType]::ParameterValue, 'Show statistics about a collection of .torrent files.')
            [CompletionResult]::new('verify', 'verify', [CompletionResultType]::ParameterValue, 'Verify files against a .torrent file.')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Prints this message or the help of the given subcommand(s)')
            break
        }
        'imdl;torrent;create' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'Use `URL` as the primary tracker announce URL. To supply multiple announce URLs, also use `--announce-tier`.')
            [CompletionResult]::new('--announce', 'announce', [CompletionResultType]::ParameterName, 'Use `URL` as the primary tracker announce URL. To supply multiple announce URLs, also use `--announce-tier`.')
            [CompletionResult]::new('-A', 'A', [CompletionResultType]::ParameterName, 'Allow `LINT`. Lints check for conditions which, although permitted, are not usually desirable. For example, piece length can be any non-zero value, but probably shouldn''t be below 16 KiB. The lint `small-piece-size` checks for this, and `--allow small-piece-size` can be used to disable this check.')
            [CompletionResult]::new('--allow', 'allow', [CompletionResultType]::ParameterName, 'Allow `LINT`. Lints check for conditions which, although permitted, are not usually desirable. For example, piece length can be any non-zero value, but probably shouldn''t be below 16 KiB. The lint `small-piece-size` checks for this, and `--allow small-piece-size` can be used to disable this check.')
            [CompletionResult]::new('-t', 't', [CompletionResultType]::ParameterName, 'Use `URL-LIST` as a tracker announce tier. Each instance adds a new tier. To add multiple trackers to a given tier, separate their announce URLs with commas:

`--announce-tier udp://example.com:80/announce,https://example.net:443/announce`
            
Announce tiers are stored in the `announce-list` key of the top-level metainfo dictionary as a list of lists of strings, as defined by BEP 12: Multitracker Metadata Extension.
            
Note: Many BitTorrent clients do not implement the behavior described in BEP 12. See the discussion here for more details: https://github.com/bittorrent/bittorrent.org/issues/82')
            [CompletionResult]::new('--announce-tier', 'announce-tier', [CompletionResultType]::ParameterName, 'Use `URL-LIST` as a tracker announce tier. Each instance adds a new tier. To add multiple trackers to a given tier, separate their announce URLs with commas:

`--announce-tier udp://example.com:80/announce,https://example.net:443/announce`
            
Announce tiers are stored in the `announce-list` key of the top-level metainfo dictionary as a list of lists of strings, as defined by BEP 12: Multitracker Metadata Extension.
            
Note: Many BitTorrent clients do not implement the behavior described in BEP 12. See the discussion here for more details: https://github.com/bittorrent/bittorrent.org/issues/82')
            [CompletionResult]::new('-c', 'c', [CompletionResultType]::ParameterName, 'Include `TEXT` as the comment for generated `.torrent` file. Stored under `comment` key of top-level metainfo dictionary.')
            [CompletionResult]::new('--comment', 'comment', [CompletionResultType]::ParameterName, 'Include `TEXT` as the comment for generated `.torrent` file. Stored under `comment` key of top-level metainfo dictionary.')
            [CompletionResult]::new('--node', 'node', [CompletionResultType]::ParameterName, 'Add DHT bootstrap node `NODE` to torrent. `NODE` should be in the form `HOST:PORT`, where `HOST` is a domain name, an IPv4 address, or an IPv6 address surrounded by brackets. May be given more than once to add multiple bootstrap nodes.

Examples:

    --node router.example.com:1337

    --node 203.0.113.0:2290

    --node [2001:db8:4275:7920:6269:7463:6f69:6e21]:8832')
            [CompletionResult]::new('-g', 'g', [CompletionResultType]::ParameterName, 'Include or exclude files that match `GLOB`. Multiple glob may be provided, with the last one taking precedence. Precede a glob with `!` to exclude it.')
            [CompletionResult]::new('--glob', 'glob', [CompletionResultType]::ParameterName, 'Include or exclude files that match `GLOB`. Multiple glob may be provided, with the last one taking precedence. Precede a glob with `!` to exclude it.')
            [CompletionResult]::new('-i', 'i', [CompletionResultType]::ParameterName, 'Read torrent contents from `PATH`. If `PATH` is a file, torrent will be a single-file torrent.  If `PATH` is a directory, torrent will be a multi-file torrent.  If `PATH` is `-`, read from standard input. Piece length defaults to 256KiB when reading from standard input if `--piece-length` is not given.')
            [CompletionResult]::new('--input', 'input', [CompletionResultType]::ParameterName, 'Read torrent contents from `PATH`. If `PATH` is a file, torrent will be a single-file torrent.  If `PATH` is a directory, torrent will be a multi-file torrent.  If `PATH` is `-`, read from standard input. Piece length defaults to 256KiB when reading from standard input if `--piece-length` is not given.')
            [CompletionResult]::new('-N', 'N', [CompletionResultType]::ParameterName, 'Set name of torrent to `TEXT`. Defaults to the filename of the argument to `--input`. Required when `--input -`.')
            [CompletionResult]::new('--name', 'name', [CompletionResultType]::ParameterName, 'Set name of torrent to `TEXT`. Defaults to the filename of the argument to `--input`. Required when `--input -`.')
            [CompletionResult]::new('--sort-by', 'sort-by', [CompletionResultType]::ParameterName, 'Set the order of files within a torrent. `SPEC` should be of the form `KEY:ORDER`, with `KEY` being one of `path` or `size`, and `ORDER` being `ascending` or `descending`. `:ORDER` defaults to `ascending` if omitted. The `--sort-by` flag may be given more than once, with later values being used to break ties. Ties that remain are broken in ascending path order.

Sort in ascending order by path, the default:

    --sort-by path:ascending

Sort in ascending order by path, more concisely:

    --sort-by path

Sort in ascending order by size, break ties in descending path order:

    --sort-by size:ascending --sort-by path:descending')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Save `.torrent` file to `TARGET`, or print to standard output if `TARGET` is `-`. Defaults to the argument to `--input` with an `.torrent` extension appended. Required when `--input -`.')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Save `.torrent` file to `TARGET`, or print to standard output if `TARGET` is `-`. Defaults to the argument to `--input` with an `.torrent` extension appended. Required when `--input -`.')
            [CompletionResult]::new('--peer', 'peer', [CompletionResultType]::ParameterName, 'Add `PEER` to magnet link.')
            [CompletionResult]::new('-p', 'p', [CompletionResultType]::ParameterName, 'Set piece length to `BYTES`. Accepts SI units, e.g. kib, mib, and gib.')
            [CompletionResult]::new('--piece-length', 'piece-length', [CompletionResultType]::ParameterName, 'Set piece length to `BYTES`. Accepts SI units, e.g. kib, mib, and gib.')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Set torrent source to `TEXT`. Stored under `source` key of info dictionary. This is useful for keeping statistics from being mis-reported when participating in swarms with the same contents, but with different trackers. When source is set to a unique value for torrents with the same contents, torrent clients will treat them as distinct torrents, and not share peers between them, and will correctly report download and upload statistics to multiple trackers.')
            [CompletionResult]::new('--source', 'source', [CompletionResultType]::ParameterName, 'Set torrent source to `TEXT`. Stored under `source` key of info dictionary. This is useful for keeping statistics from being mis-reported when participating in swarms with the same contents, but with different trackers. When source is set to a unique value for torrents with the same contents, torrent clients will treat them as distinct torrents, and not share peers between them, and will correctly report download and upload statistics to multiple trackers.')
            [CompletionResult]::new('-n', 'n', [CompletionResultType]::ParameterName, 'Skip writing `.torrent` file to disk.')
            [CompletionResult]::new('--dry-run', 'dry-run', [CompletionResultType]::ParameterName, 'Skip writing `.torrent` file to disk.')
            [CompletionResult]::new('-F', 'F', [CompletionResultType]::ParameterName, 'Follow symlinks in torrent input. By default, symlinks to files and directories are not included in torrent contents.')
            [CompletionResult]::new('--follow-symlinks', 'follow-symlinks', [CompletionResultType]::ParameterName, 'Follow symlinks in torrent input. By default, symlinks to files and directories are not included in torrent contents.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite the destination `.torrent` file, if it exists.')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite the destination `.torrent` file, if it exists.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Include hidden files that would otherwise be skipped, such as files that start with a `.`, and files hidden by file attributes on macOS and Windows.')
            [CompletionResult]::new('--include-hidden', 'include-hidden', [CompletionResultType]::ParameterName, 'Include hidden files that would otherwise be skipped, such as files that start with a `.`, and files hidden by file attributes on macOS and Windows.')
            [CompletionResult]::new('-j', 'j', [CompletionResultType]::ParameterName, 'Include junk files that would otherwise be skipped.')
            [CompletionResult]::new('--include-junk', 'include-junk', [CompletionResultType]::ParameterName, 'Include junk files that would otherwise be skipped.')
            [CompletionResult]::new('--link', 'link', [CompletionResultType]::ParameterName, 'Print created torrent `magnet:` URL to standard output')
            [CompletionResult]::new('-M', 'M', [CompletionResultType]::ParameterName, 'Include MD5 checksum of each file in the torrent. N.B. MD5 is cryptographically broken and only suitable for checking for accidental corruption.')
            [CompletionResult]::new('--md5', 'md5', [CompletionResultType]::ParameterName, 'Include MD5 checksum of each file in the torrent. N.B. MD5 is cryptographically broken and only suitable for checking for accidental corruption.')
            [CompletionResult]::new('--no-created-by', 'no-created-by', [CompletionResultType]::ParameterName, 'Do not populate `created by` key of generated torrent with imdl version information.')
            [CompletionResult]::new('--no-creation-date', 'no-creation-date', [CompletionResultType]::ParameterName, 'Do not populate `creation date` key of generated torrent with current time.')
            [CompletionResult]::new('-O', 'O', [CompletionResultType]::ParameterName, 'Open `.torrent` file after creation. Uses `xdg-open`, `gnome-open`, or `kde-open` on Linux; `open` on macOS; and `cmd /C start` on Windows')
            [CompletionResult]::new('--open', 'open', [CompletionResultType]::ParameterName, 'Open `.torrent` file after creation. Uses `xdg-open`, `gnome-open`, or `kde-open` on Linux; `open` on macOS; and `cmd /C start` on Windows')
            [CompletionResult]::new('-P', 'P', [CompletionResultType]::ParameterName, 'Set the `private` flag. Torrent clients that understand the flag and participate in the swarm of a torrent with the flag set will only announce themselves to the announce URLs included in the torrent, and will not use other peer discovery mechanisms, such as the DHT or local peer discovery. See BEP 27: Private Torrents for more information.')
            [CompletionResult]::new('--private', 'private', [CompletionResultType]::ParameterName, 'Set the `private` flag. Torrent clients that understand the flag and participate in the swarm of a torrent with the flag set will only announce themselves to the announce URLs included in the torrent, and will not use other peer discovery mechanisms, such as the DHT or local peer discovery. See BEP 27: Private Torrents for more information.')
            [CompletionResult]::new('-S', 'S', [CompletionResultType]::ParameterName, 'Display information about created torrent file.')
            [CompletionResult]::new('--show', 'show', [CompletionResultType]::ParameterName, 'Display information about created torrent file.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;link' {
            [CompletionResult]::new('-i', 'i', [CompletionResultType]::ParameterName, 'Generate magnet link from metainfo at `PATH`. If `PATH` is `-`, read metainfo from standard input.')
            [CompletionResult]::new('--input', 'input', [CompletionResultType]::ParameterName, 'Generate magnet link from metainfo at `PATH`. If `PATH` is `-`, read metainfo from standard input.')
            [CompletionResult]::new('-p', 'p', [CompletionResultType]::ParameterName, 'Add `PEER` to magnet link.')
            [CompletionResult]::new('--peer', 'peer', [CompletionResultType]::ParameterName, 'Add `PEER` to magnet link.')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Select files to download. Values are indices into the `info.files` list, e.g. `--select-only 1,2,3`.')
            [CompletionResult]::new('--select-only', 'select-only', [CompletionResultType]::ParameterName, 'Select files to download. Values are indices into the `info.files` list, e.g. `--select-only 1,2,3`.')
            [CompletionResult]::new('-O', 'O', [CompletionResultType]::ParameterName, 'Open generated magnet link. Uses `xdg-open`, `gnome-open`, or `kde-open` on Linux; `open` on macOS; and `cmd /C start` on Windows.')
            [CompletionResult]::new('--open', 'open', [CompletionResultType]::ParameterName, 'Open generated magnet link. Uses `xdg-open`, `gnome-open`, or `kde-open` on Linux; `open` on macOS; and `cmd /C start` on Windows.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;piece-length' {
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;show' {
            [CompletionResult]::new('-i', 'i', [CompletionResultType]::ParameterName, 'Show information about torrent at `PATH`. If `Path` is `-`, read torrent metainfo from standard input.')
            [CompletionResult]::new('--input', 'input', [CompletionResultType]::ParameterName, 'Show information about torrent at `PATH`. If `Path` is `-`, read torrent metainfo from standard input.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;stats' {
            [CompletionResult]::new('-l', 'l', [CompletionResultType]::ParameterName, 'Stop after processing `N` torrents. Useful when processing large collections of `.torrent` files.')
            [CompletionResult]::new('--limit', 'limit', [CompletionResultType]::ParameterName, 'Stop after processing `N` torrents. Useful when processing large collections of `.torrent` files.')
            [CompletionResult]::new('-e', 'e', [CompletionResultType]::ParameterName, 'Extract and display values under key paths that match `REGEX`. Subkeys of a bencodeded dictionary are delimited by `/`, and values of a bencoded list are delmited by `*`. For example, given the following bencoded dictionary `{"foo": [{"bar": {"baz": 2}}]}`, the value `2`''s key path will be `foo*bar/baz`. The value `2` would be displayed if any of `bar`, `foo[*]bar/baz`, or `foo.*baz` were passed to `--extract-pattern.')
            [CompletionResult]::new('--extract-pattern', 'extract-pattern', [CompletionResultType]::ParameterName, 'Extract and display values under key paths that match `REGEX`. Subkeys of a bencodeded dictionary are delimited by `/`, and values of a bencoded list are delmited by `*`. For example, given the following bencoded dictionary `{"foo": [{"bar": {"baz": 2}}]}`, the value `2`''s key path will be `foo*bar/baz`. The value `2` would be displayed if any of `bar`, `foo[*]bar/baz`, or `foo.*baz` were passed to `--extract-pattern.')
            [CompletionResult]::new('-i', 'i', [CompletionResultType]::ParameterName, 'Search `PATH` for torrents. May be a directory or a single torrent file.')
            [CompletionResult]::new('--input', 'input', [CompletionResultType]::ParameterName, 'Search `PATH` for torrents. May be a directory or a single torrent file.')
            [CompletionResult]::new('-p', 'p', [CompletionResultType]::ParameterName, 'Pretty print the contents of each torrent as it is processed.')
            [CompletionResult]::new('--print', 'print', [CompletionResultType]::ParameterName, 'Pretty print the contents of each torrent as it is processed.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;verify' {
            [CompletionResult]::new('-i', 'i', [CompletionResultType]::ParameterName, 'Verify torrent contents against torrent metainfo in `METAINFO`. If `METAINFO` is `-`, read metainfo from standard input.')
            [CompletionResult]::new('--input', 'input', [CompletionResultType]::ParameterName, 'Verify torrent contents against torrent metainfo in `METAINFO`. If `METAINFO` is `-`, read metainfo from standard input.')
            [CompletionResult]::new('-c', 'c', [CompletionResultType]::ParameterName, 'Verify torrent content at `PATH` against torrent metainfo. Defaults to `name` field of torrent info dictionary.')
            [CompletionResult]::new('--content', 'content', [CompletionResultType]::ParameterName, 'Verify torrent content at `PATH` against torrent metainfo. Defaults to `name` field of torrent info dictionary.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;torrent;help' {
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Prints help information')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Prints help information')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Prints version information')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Prints version information')
            break
        }
        'imdl;completions' {
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Print completion script for `SHELL`.')
            [CompletionResult]::new('--shell', 'shell', [CompletionResultType]::ParameterName, 'Print completion script for `SHELL`.')
            [CompletionResult]::new('-d', 'd', [CompletionResultType]::ParameterName, 'Write completion script to `DIR` with an appropriate filename. If `--shell` is not given, write all completion scripts.')
            [CompletionResult]::new('--dir', 'dir', [CompletionResultType]::ParameterName, 'Write completion script to `DIR` with an appropriate filename. If `--shell` is not given, write all completion scripts.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help message.')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Print version number.')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Print version number.')
            break
        }
        'imdl;help' {
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Prints help information')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Prints help information')
            [CompletionResult]::new('-V', 'V', [CompletionResultType]::ParameterName, 'Prints version information')
            [CompletionResult]::new('--version', 'version', [CompletionResultType]::ParameterName, 'Prints version information')
            break
        }
    })

    $completions.Where{ $_.CompletionText -like "$wordToComplete*" } |
        Sort-Object -Property ListItemText
}
